==> tine20-allinone_2020.08.8.tar.bz2: Setup/js/Setup-lang-it-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Italian (http://www.transifex.com/tine20/tine20/language/it/)\nLanguage: it\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "I have read the license agreement and accept it"
: "Ho letto l'informativa di licenza e lo accetto"

, "License Agreement"
: "Informativa di Licenza"

, "I have read the privacy agreement and accept it"
: "Ho letto l'accordo"

, "Privacy Agreement"
: "Informativa della Privacy"

, "Accept Terms and Conditions"
: "Accetto i Termini e le Condizioni"

, "Backend"
: "Sistema"

, "Standard IMAP"
: "IMAP Standard"

, "Standard SMTP"
: "SMTP Standard"

, "Imap"
: "Imap"

, "Hostname"
: "Nome host"

, "Username"
: "Nome utente"

, "Password"
: "Password"

, "Port"
: "Porta"

, "Secure Connection"
: "Connessione Sicura"

, "None"
: "Nessuno"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Verify peer Certificate"
: ""

, "Use system account"
: "Usa l'account di sistema"

, "No"
: "No"

, "Yes"
: "Yes"

, "Append domain to login name"
: "Aggiungi il dominio al nome di login"

, "Use email address as login name"
: ""

, "Cyrus Admin"
: "Amministratore Cyrus"

, "Cyrus Admin Password"
: "Password Admin Cyrus"

, "Use proxy auth"
: "Utilizza autenticazione proxy"

, "Smtp"
: "Smtp"

, "Authentication"
: "Autenticazione"

, "Login"
: "Login"

, "Plain"
: "Plain"

, "Primary Domain"
: "Dominio Primario"

, "Secondary Domains (comma separated)"
: "Domini Secondari (separati da virgole)"

, "Notifications service address"
: "Indirizzo notifiche di servizio"

, "Notification Username"
: "Username di notifica"

, "Notification Password"
: "Password di notifica"

, "Notifications local client (hostname or IP address)"
: "Notifica client locali (nome host o indirizzo IP)"

, "SIEVE"
: "SIEVE"

, "MySql Hostname"
: "Nome host MySql"

, "MySql Database"
: "Database MySql"

, "MySql User"
: "Utente MySql"

, "MySql Password"
: "Password MySql"

, "MySql Port"
: "Porta MySql"

, "User or UID"
: "Utente o UID"

, "Group or GID"
: "Gruppo o GID"

, "Home Template"
: "Template Home"

, "Password Scheme"
: "Schema password"

, "PLAIN-MD5"
: "PLAIN-MD5"

, "MD5-CRYPT"
: "MD5-CRYPT"

, "SHA1"
: "SHA1"

, "SHA256"
: "SHA256"

, "SSHA256"
: "SSHA256"

, "SHA512"
: "SHA512"

, "SSHA512"
: "SSHA512"

, "PLAIN"
: "PLAIN"

, "Terms and Conditions"
: "Termini e Condizioni"

, "Setup Checks"
: "Controlli di installazione"

, "Config Manager"
: "Manager di Configurazione"

, "Authentication/Accounts"
: "Autenticazione/Account"

, "Email"
: "Email"

, "Application Manager"
: "Manager di Applicazione"

, "Setup"
: ""

, "Name"
: "Nome"

, "Enabled"
: "Abilitato"

, "Order"
: "Ordine"

, "Installed Version"
: "Versione Installata"

, "Available Version"
: "Versione Disponibile"

, "Status"
: "Stato"

, "Depends on"
: "Dipende da"

, "Install application"
: "Installa applicazione"

, "Uninstall application"
: "Disinstalla applicazione"

, "Update application"
: "Aggiorna applicazione"

, "Go to {0} login"
: "Vai a {0} login"

, "uninstall"
: "disinstalla"

, "Do you really want to uninstall the application(s)?"
: "Vuoi veramente disinstallare la/le applicazioni?"

, "This may take a while"
: "Potrebbe richiedere del tempo"

, "Dependency Violation"
: "Violazione di dipendenze"

, "CLI Required"
: ""

, "Delete all existing users and groups"
: "Cancella tutte gli utenti e i gruppi esistenti"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "Il passaggio da SQL a LDAP cancellerà tutti gli Account Utente esistenti, i Gruppi e i Ruoli. Vuoi veramente migrare il sistema di memorizzazione account a LDAP?"

, "TLS client certificate"
: ""

, "Initial Admin User"
: "Utente Admin iniziale"

, "Initial admin login name"
: "Nome login iniziale amministratore"

, "Initial admin Password"
: "Password iniziale amministratore"

, "Password confirmation"
: "Conferma password"

, "Authentication provider"
: "Provider di autenticazione"

, "Try to split username"
: "Prova a dividere il nome utente"

, "Account canonical form"
: "Form canonica account"

, "Account domain name"
: ""

, "Account domain short name"
: "Nome breve di dominio dell'account"

, "Host"
: "Host"

, "Login name"
: "Nome login"

, "Bind requires DN"
: "Bind richiede DN"

, "Start TLS"
: "Start TLS"

, "Base DN"
: "DN base"

, "Search filter"
: "Filtro di ricerca"

, "Certificate validation"
: ""

, "CA file"
: ""

, "CRL directory"
: ""

, "Accounts storage"
: "Sistema di salvataggio Account"

, "Default user group name"
: "Nome gruppo utenti di default"

, "Default admin group name"
: "Nome gruppo amministratori di default"

, "Login panel"
: "Pannello di login"

, "Reuse last username logged"
: "Riutilizza l'ultimo username loggato"

, "Password Settings"
: "Impostazione Password"

, "User can change password"
: "L'utente può cambiare la password"

, "Enable password policy"
: "Abilita le politiche sulle password"

, "Only ASCII"
: "Solo ASCII"

, "Minimum length"
: "Lunghezza minima"

, "Minimum word chars"
: "Numero caratteri minimo per parola"

, "Minimum uppercase chars"
: "Numero caratteri maiuscoli minimi"

, "Minimum special chars"
: "Numero caratteri speciali minimi"

, "Minimum numbers"
: "Numero caratteri numerici minimi"

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: "Vietato utilizzare parte del nome utente nella password"

, "Redirect Settings"
: "Impostazioni di redirezione"

, "Redirect Url (redirect to login screen if empty)"
: "Indirizzo di redirezione (redirige alla schermata di login se vuoto)"

, "Redirect Always (if No, only redirect after logout)"
: "Redirigi Sempre (se No, redirige solamente dopo logout)"

, "Redirect to referring site, if exists"
: "Redirige al sito di riferimento, se esiste"

, "Password encoding"
: "Encoding della password"

, "des"
: "des"

, "crypt"
: ""

, "blowfish_crypt"
: "blowfish_crypt"

, "md5_crypt"
: "md5_crypt"

, "ext_crypt"
: "ext_crypt"

, "md5"
: "md5"

, "smd5"
: "smd5"

, "sha"
: "sha"

, "ssha"
: "ssha"

, "ntpassword"
: "ntpassword"

, "plain"
: "plain"

, "User DN"
: "DN Utente"

, "User Filter"
: "Filtro utente"

, "User Search Scope"
: "Ambito di ricerca utente"

, "Groups DN"
: "DN Gruppo"

, "Group Filter"
: "Filtro gruppo"

, "Group Search Scope"
: "Ambito di ricerca utente "

, "Use Rfc 2307 bis"
: "Usa Rfc 2307 bis"

, "Maintain RFC 2307 attributes"
: "Mantieni attributi RFC 2307"

, "Min User Id"
: "Minimo Id Utente"

, "Max User Id"
: "Massimo Id Utente"

, "Min Group Id"
: "Min Id Gruppo"

, "Max Group Id"
: "Massimo Id Gruppo"

, "Group UUID Attribute name"
: "Nome Attributo UUID Gruppo"

, "User UUID Attribute name"
: "Nome Attributo UUID Utente"

, "Readonly access"
: "Accesso in sola lettura"

, "Save config and install"
: "Salva configurazione e installa"

, "Save config"
: "Salva configurazione"

, "Passwords don't match"
: "Le password non corrispondono"

, "Should not be empty"
: "Non dovrebbe essere vuota"

, "Performing Environment Checks..."
: "Esecuzione Controlli di Ambiente..."

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: "Non è stato trovato alcun {0}. Prova a cambiare i criteri del filtro, le opzioni di visualizzazione o {1} nella tua ricerca"

, "Check"
: "Controlla"

, "Result"
: "Risultati"

, "Error"
: "Errore"

, "Run setup tests"
: "Avvia test di installazione"

, "Ignore setup tests"
: "Ignora test di installazione"

, "Application, Applications"
: [
  "Applicazione"
 ,"Applicazioni"

]
, "File"
: "File"

, "Setup Authentication"
: "Impostazione Autenticazione"

, "Database"
: "Database"

, "User"
: "Utente"

, "Prefix"
: "Prefisso"

, "Logging"
: "Logging"

, "Filename"
: "Nome file"

, "Priority"
: "Priorità"

, "Caching"
: "Caching"

, "Lifetime (seconds)"
: "Tempo di vita (secondi)"

, "Path"
: "Percorso"

, "Queue"
: "Coda"

, "Session"
: "Sessione"

, "Temporary files"
: "File Temporanei"

, "Temporary Files Path"
: "Percorso File Temporanei"

, "Filestore directory"
: "Directory di salvataggio"

, "Filestore Path"
: "Percorso di salvataggio"

, "Addressbook Map panel"
: "Pannello Mappa Rubrica"

, "Map panel"
: "Pannello Mappa"

, "disabled"
: "disabilitato"

, "enabled"
: "abilitato"

, "Config file is not writable"
: "Il file di Configurazione non è scrivibile"

, "Download config file"
: "Scarica il file di Configurazione"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Application"
: "Applicazione"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Setup/js/Setup-lang-it-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:59+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Italian (http://www.transifex.com/tine20/tine20/language/it/)\nLanguage: it\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Performing Environment Checks..."
: "Esecuzione Controlli di Ambiente..."

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: "Non è stato trovato alcun {0}. Prova a cambiare i criteri del filtro, le opzioni di visualizzazione o {1} nella tua ricerca"

, "Check"
: "Controlla"

, "Result"
: "Risultati"

, "Message"
: ""

, "Run setup tests"
: "Avvia test di installazione"

, "Ignore setup tests"
: "Ignora test di installazione"

, "Install application"
: "Installa applicazione"

, "Name"
: "Nome"

, "Enabled"
: "Abilitato"

, "Order"
: "Ordine"

, "Installed Version"
: "Versione Installata"

, "Available Version"
: "Versione Disponibile"

, "Status"
: "Stato"

, "Depends on"
: "Dipende da"

, "Uninstall application"
: "Disinstalla applicazione"

, "Update applications"
: ""

, "Go to {0} login"
: "Vai a {0} login"

, "uninstall"
: "disinstalla"

, "Do you really want to uninstall the application(s)?"
: "Vuoi veramente disinstallare la/le applicazioni?"

, "This may take a while"
: "Potrebbe richiedere del tempo"

, "Dependency Violation"
: "Violazione di dipendenze"

, "CLI Required"
: ""

, "Delete all existing users and groups"
: "Cancella tutte gli utenti e i gruppi esistenti"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "Il passaggio da SQL a LDAP cancellerà tutti gli Account Utente esistenti, i Gruppi e i Ruoli. Vuoi veramente migrare il sistema di memorizzazione account a LDAP?"

, "Backend"
: "Sistema"

, "TLS client certificate"
: ""

, "Initial Admin User"
: "Utente Admin iniziale"

, "Initial admin login name"
: "Nome login iniziale amministratore"

, "Initial admin Password"
: "Password iniziale amministratore"

, "Password confirmation"
: "Conferma password"

, "Authentication provider"
: "Provider di autenticazione"

, "Try to split username"
: "Prova a dividere il nome utente"

, "Yes"
: "Yes"

, "No"
: "No"

, "Account canonical form"
: "Form canonica account"

, "Account domain name"
: ""

, "Account domain short name"
: "Nome breve di dominio dell'account"

, "Host"
: "Host"

, "Login name"
: "Nome login"

, "Password"
: "Password"

, "Bind requires DN"
: "Bind richiede DN"

, "Start TLS"
: "Start TLS"

, "SSL"
: "SSL"

, "Port"
: "Porta"

, "Base DN"
: "DN base"

, "Search filter"
: "Filtro di ricerca"

, "Hostname"
: "Nome host"

, "Secure Connection"
: "Connessione Sicura"

, "None"
: "Nessuno"

, "TLS"
: "TLS"

, "Append domain to login name"
: "Aggiungi il dominio al nome di login"

, "Certificate validation"
: ""

, "CA file"
: ""

, "CRL directory"
: ""

, "Accounts storage"
: "Sistema di salvataggio Account"

, "Default user group name"
: "Nome gruppo utenti di default"

, "Default admin group name"
: "Nome gruppo amministratori di default"

, "Login panel"
: "Pannello di login"

, "Reuse last username logged"
: "Riutilizza l'ultimo username loggato"

, "Password Settings"
: "Impostazione Password"

, "User can change password"
: "L'utente può cambiare la password"

, "Enable password policy"
: "Abilita le politiche sulle password"

, "Only ASCII"
: "Solo ASCII"

, "Minimum length"
: "Lunghezza minima"

, "Minimum word chars"
: "Numero caratteri minimo per parola"

, "Minimum uppercase chars"
: "Numero caratteri maiuscoli minimi"

, "Minimum special chars"
: "Numero caratteri speciali minimi"

, "Minimum numbers"
: "Numero caratteri numerici minimi"

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: "Vietato utilizzare parte del nome utente nella password"

, "Redirect Settings"
: "Impostazioni di redirezione"

, "Redirect Url (redirect to login screen if empty)"
: "Indirizzo di redirezione (redirige alla schermata di login se vuoto)"

, "Redirect Always (if No, only redirect after logout)"
: "Redirigi Sempre (se No, redirige solamente dopo logout)"

, "Redirect to referring site, if exists"
: "Redirige al sito di riferimento, se esiste"

, "Password encoding"
: "Encoding della password"

, "des"
: "des"

, "crypt"
: ""

, "blowfish_crypt"
: "blowfish_crypt"

, "md5_crypt"
: "md5_crypt"

, "ext_crypt"
: "ext_crypt"

, "md5"
: "md5"

, "smd5"
: "smd5"

, "sha"
: "sha"

, "ssha"
: "ssha"

, "ntpassword"
: "ntpassword"

, "plain"
: "plain"

, "User DN"
: "DN Utente"

, "User Filter"
: "Filtro utente"

, "User Search Scope"
: "Ambito di ricerca utente"

, "Groups DN"
: "DN Gruppo"

, "Group Filter"
: "Filtro gruppo"

, "Group Search Scope"
: "Ambito di ricerca utente "

, "Use Rfc 2307 bis"
: "Usa Rfc 2307 bis"

, "Maintain RFC 2307 attributes"
: "Mantieni attributi RFC 2307"

, "Min User Id"
: "Minimo Id Utente"

, "Max User Id"
: "Massimo Id Utente"

, "Min Group Id"
: "Min Id Gruppo"

, "Max Group Id"
: "Massimo Id Gruppo"

, "Group UUID Attribute name"
: "Nome Attributo UUID Gruppo"

, "User UUID Attribute name"
: "Nome Attributo UUID Utente"

, "Readonly access"
: "Accesso in sola lettura"

, "Save config and install"
: "Salva configurazione e installa"

, "Save config"
: "Salva configurazione"

, "Passwords don't match"
: "Le password non corrispondono"

, "Should not be empty"
: "Non dovrebbe essere vuota"

, "File"
: "File"

, "Setup Authentication"
: "Impostazione Autenticazione"

, "Username"
: "Nome utente"

, "Database"
: "Database"

, "User"
: "Utente"

, "Prefix"
: "Prefisso"

, "Logging"
: "Logging"

, "Filename"
: "Nome file"

, "Priority"
: "Priorità"

, "Caching"
: "Caching"

, "Lifetime (seconds)"
: "Tempo di vita (secondi)"

, "Path"
: "Percorso"

, "Queue"
: "Coda"

, "Session"
: "Sessione"

, "Temporary files"
: "File Temporanei"

, "Temporary Files Path"
: "Percorso File Temporanei"

, "Filestore directory"
: "Directory di salvataggio"

, "Filestore Path"
: "Percorso di salvataggio"

, "Addressbook Map panel"
: "Pannello Mappa Rubrica"

, "Map panel"
: "Pannello Mappa"

, "disabled"
: "disabilitato"

, "enabled"
: "abilitato"

, "Config file is not writable"
: "Il file di Configurazione non è scrivibile"

, "Download config file"
: "Scarica il file di Configurazione"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Standard IMAP"
: "IMAP Standard"

, "Standard SMTP"
: "SMTP Standard"

, "Imap"
: "Imap"

, "Verify peer Certificate"
: ""

, "Use system account"
: "Usa l'account di sistema"

, "Use email address as login name"
: ""

, "Cyrus Admin"
: "Amministratore Cyrus"

, "Cyrus Admin Password"
: "Password Admin Cyrus"

, "Use proxy auth"
: "Utilizza autenticazione proxy"

, "Smtp"
: "Smtp"

, "Authentication"
: "Autenticazione"

, "Login"
: "Login"

, "Plain"
: "Plain"

, "Primary Domain"
: "Dominio Primario"

, "Secondary Domains (comma separated)"
: "Domini Secondari (separati da virgole)"

, "Notifications service address"
: "Indirizzo notifiche di servizio"

, "Notification Username"
: "Username di notifica"

, "Notification Password"
: "Password di notifica"

, "Notifications local client (hostname or IP address)"
: "Notifica client locali (nome host o indirizzo IP)"

, "SIEVE"
: "SIEVE"

, "MySql Hostname"
: "Nome host MySql"

, "MySql Database"
: "Database MySql"

, "MySql User"
: "Utente MySql"

, "MySql Password"
: "Password MySql"

, "MySql Port"
: "Porta MySql"

, "User or UID"
: "Utente o UID"

, "Group or GID"
: "Gruppo o GID"

, "Home Template"
: "Template Home"

, "Password Scheme"
: "Schema password"

, "PLAIN-MD5"
: "PLAIN-MD5"

, "MD5-CRYPT"
: "MD5-CRYPT"

, "SHA1"
: "SHA1"

, "SHA256"
: "SHA256"

, "SSHA256"
: "SSHA256"

, "SHA512"
: "SHA512"

, "SSHA512"
: "SSHA512"

, "PLAIN"
: "PLAIN"

, "Setup"
: ""

, "Application, Applications"
: [
  "Applicazione"
 ,"Applicazioni"

]
, "Terms and Conditions"
: "Termini e Condizioni"

, "Setup Checks"
: "Controlli di installazione"

, "Config Manager"
: "Manager di Configurazione"

, "Authentication/Accounts"
: "Autenticazione/Account"

, "Email"
: "Email"

, "Application Manager"
: "Manager di Applicazione"

, "I have read the license agreement and accept it"
: "Ho letto l'informativa di licenza e lo accetto"

, "License Agreement"
: "Informativa di Licenza"

, "I have read the privacy agreement and accept it"
: "Ho letto l'accordo"

, "Privacy Agreement"
: "Informativa della Privacy"

, "Accept Terms and Conditions"
: "Accetto i Termini e le Condizioni"


, "Application"
: "Applicazione"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
